@@ -7,6 +7,7 @@
  * Contract with IBM Corp.
  ****************************************************************************** */
 /* Copyright (c) 2020 Red Hat, Inc. */
+/* Copyright Contributors to the Open Cluster Management project */
 
 import supertest from 'supertest';
 import nock from 'nock';
@@ -150,7 +151,7 @@ describe('Policy Resolver', () => {
               uid
             }
             status
-            enforcement
+            remediation
             detail {
               exclude_namespace
               include_namespace
