@@ -7,6 +7,8 @@
  * Contract with IBM Corp.
  ****************************************************************************** */
 /* Copyright (c) 2020 Red Hat, Inc. */
+/* Copyright Contributors to the Open Cluster Management project */
+
 import { gql } from 'apollo-server-express';
 
 export const typeDef = gql`
@@ -27,6 +29,20 @@ type Query {
 
   # Get any kubernetes resource from any managed cluster.
   getResource(kind: String, name: String, namespace: String, cluster: String, selfLink: String, updateInterval: Int, deleteAfterUse: Boolean): JSON
+  getUserAccessCredentials: JSON
+
+  # Get Policy Automation list
+  policyAutomations(namespace: String): [PolicyAutomation]
+  # Get Ansible Tower Job Templates
+  ansibleJobTemplates(host: String!, token: String!): [AnsibleJobTemplate]
+  # Get Ansible Credentials
+  ansibleCredentials(name: String, namespace: String): [AnsibleCredential]
+  # Copy and return secret name for given Ansible credential
+  copyAnsibleSecret(name: String!, namespace: String!, targetNamespace: String!): AnsibleSecretName
+  # Ansible Automation History
+  ansibleAutomationHistories(name: String!, namespace: String!): [AnsibleAutomationHistory]
+  # Ansible Operator Installed
+  ansibleOperatorInstalled(namespace: String!): AnsibleOperatorInstalled
 }
 
 type Mutation {
@@ -51,6 +67,9 @@ type Mutation {
   # Creates Kubernetes Resources that do not exist and updates those that do exist
   createAndUpdateResources(toCreate: [JSON], toUpdate: [JSON]): JSON
 
+  # Create Policy Automation that do not exist and updates those that do exist
+  modifyPolicyAutomation(poliyAutomationJSON: [JSON], action: String!): JSON
+
   # Update Kubernetes resources
   updateResource(namespace: String!, name: String!, body: JSON, selfLink: String!, resourcePath: String): JSON
 
